# Basic Settings
Configure basic workspace settings.
In this section, you can find information on workspace settings listed under Basic Settings in the administration area. Browse through the pages in this section to find topics that are most relevant to you.
